@@ -2,11 +2,8 @@ use strict;
 use warnings;
 package App::bovespa;
 
-use HTML::TreeBuilder;
 use LWP::UserAgent;
-
-# TODO = multiple providers
-#my $url = "https://br.financas.yahoo.com/q?s=PETR4.SA";
+use JSON;
 
 my $agent_string = "Mozilla/5.0 (Windows NT 6.3; rv:36.0) Gecko/20100101 Firefox/36.0";
 
@@ -27,27 +24,43 @@ sub stock {
 sub yahoo {
     my ( $self, $stock ) = @_;
 
-    my $url = "https://br.financas.yahoo.com/q?s=";
-    $stock = uc $stock . ".sa";
+    my $url = "https://query.yahooapis.com/v1/public/yql";
+
+    #$stock = uc $stock . ".sa";
+    $stock = uc $stock;
+    my $yahoo_query = "select * from yahoo.finance.quotes where symbol in ( \"$stock\" )";
 
     my $ua = LWP::UserAgent->new();
     $ua->ssl_opts( verify_hostname => 0 );
     $ua->timeout( 10 );
 
-    my $response = $ua->get( $url . $stock );
+    $DB::single = 1;
+
+    my %url_params = (
+        q           => $yahoo_query,
+        format      => "json",
+        env         => "store://datatables.org/alltableswithkeys", 
+        callback    => undef,
+    );
+
+
+    my $query_params = "?";
+    while ( my ( $key, $value ) = each( %url_params ) ) {
+        $query_params .=  "$key=" . ( $value ? $value : '' ). "\&";
+    }
+
+    my $response = $ua->get( $url . $query_params );
+
     my $raw_html;
     if ( $response->is_success ){
         $raw_html = $response->decoded_content;
     }else{
-        die $response->status_line;
+        die;
     }
 
-    my $tree = HTML::TreeBuilder->new();
-    $tree->parse( $raw_html );
+    my $data = decode_json $raw_html;
+    return $data->{ query }{ results }{ quote }{ Bid };
 
-    for ( $tree->find_by_attribute('id', "yfs_l84_". lc $stock )){
-        return join "", grep { ref $_ ne "SCALAR" } $_->content_list;
-    }
 }
 
 =head1 NAME
@@ -56,7 +69,7 @@ App::bovespa - Simple tool to follow up your stocks at Bovespa Stock Exchange
 
 =head1 VERSION
 
-Version 0.002
+Version 0.003
 
 =head1 SYNOPSIS
 
@@ -72,7 +85,7 @@ To get a stock cotation is plain simple:
     use App::bovespa;
 
     my $exchange = App::bovespa->new();
-    my $cotation = $exchange->stock( "PETR4" );
+    my $cotation = $exchange->stock( "PETR4.SA" );
 
 Also inside this distribution, comes a small tool called bovespa_report, it has
 a wrapper for cotation and a parser for a file with a list of cotations and prices to
@@ -86,8 +99,8 @@ Will display all options related with the tool
 
 =head2 stock
 
-Receives a stock name and returns it cotation. The name must be four letters and the type digit.
-Like "PETR4" or "PETR3"
+Receives a stock name and returns it cotation. The name must the symbol name for the stock and the type digit.
+Like "PETR4.SA" or "PETR3.SA"
 
 =head1 AUTHOR
 
@@ -98,13 +111,9 @@ RECSKY, C<< recsky at cpan.org >>
 In case of one of providers change it page or something like that, the lib may broke. In this case
 contact me at recsky@cpan.org
 
-Or at irc at irc.perl.org
-
-    #sao-paulo.pm
-
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2015 RECSKY
+Copyright 2015
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
